@@ -489,9 +489,9 @@ suite('PeoplePageAccountSettings', function() {
     assertTrue(isChildVisible(peoplePage, '#google-services'));
     assertFalse(isChildVisible(peoplePage, '#sync-setup'));
 
-    // The other rows are shown correctly.
+    // The other rows are shown/hidden correctly.
     assertTrue(isChildVisible(peoplePage, '#edit-profile'));
-    assertTrue(isChildVisible(peoplePage, '#manage-google-account'));
+    assertFalse(isChildVisible(peoplePage, '#manage-google-account'));
     assertTrue(isChildVisible(peoplePage, '#importDataDialogTrigger'));
   });
 
@@ -507,7 +507,7 @@ suite('PeoplePageAccountSettings', function() {
     assertTrue(isChildVisible(peoplePage, '#google-services'));
     assertFalse(isChildVisible(peoplePage, '#sync-setup'));
 
-    // The other rows are shown correctly.
+    // The other rows are shown/hidden correctly.
     assertTrue(isChildVisible(peoplePage, '#edit-profile'));
     assertFalse(isChildVisible(peoplePage, '#manage-google-account'));
     assertTrue(isChildVisible(peoplePage, '#importDataDialogTrigger'));
@@ -526,9 +526,9 @@ suite('PeoplePageAccountSettings', function() {
     assertFalse(isChildVisible(peoplePage, '#google-services'));
     assertTrue(isChildVisible(peoplePage, '#sync-setup'));
 
-    // The other rows are shown correctly.
+    // The other rows are shown/hidden correctly.
     assertTrue(isChildVisible(peoplePage, '#edit-profile'));
-    assertTrue(isChildVisible(peoplePage, '#manage-google-account'));
+    assertFalse(isChildVisible(peoplePage, '#manage-google-account'));
     assertTrue(isChildVisible(peoplePage, '#importDataDialogTrigger'));
   });
 
@@ -544,9 +544,9 @@ suite('PeoplePageAccountSettings', function() {
     assertTrue(isChildVisible(peoplePage, '#google-services'));
     assertFalse(isChildVisible(peoplePage, '#sync-setup'));
 
-    // The other rows are shown correctly.
+    // The other rows are shown/hidden correctly.
     assertTrue(isChildVisible(peoplePage, '#edit-profile'));
-    assertTrue(isChildVisible(peoplePage, '#manage-google-account'));
+    assertFalse(isChildVisible(peoplePage, '#manage-google-account'));
     assertTrue(isChildVisible(peoplePage, '#importDataDialogTrigger'));
   });
 
@@ -561,9 +561,9 @@ suite('PeoplePageAccountSettings', function() {
     assertTrue(isChildVisible(peoplePage, '#google-services'));
     assertFalse(isChildVisible(peoplePage, '#sync-setup'));
 
-    // The other rows are shown correctly.
+    // The other rows are shown/hidden correctly.
     assertTrue(isChildVisible(peoplePage, '#edit-profile'));
-    assertTrue(isChildVisible(peoplePage, '#manage-google-account'));
+    assertFalse(isChildVisible(peoplePage, '#manage-google-account'));
     assertTrue(isChildVisible(peoplePage, '#importDataDialogTrigger'));
   });
 
@@ -599,7 +599,7 @@ suite('PeoplePageAccountSettings', function() {
                                   '#account-name')!.textContent!.trim();
     const accountEmail =
         peoplePage.shadowRoot!.querySelector(
-                                  '#account-email')!.textContent!.trim();
+                                  '#account-subtitle')!.textContent!.trim();
 
     assertEquals(expectedAccount.fullName, accountName);
     assertEquals(expectedAccount.email, accountEmail);
@@ -609,5 +609,26 @@ suite('PeoplePageAccountSettings', function() {
                                   '#profile-icon')!.style.backgroundImage;
     assertTrue(bgImage.includes(expectedAccount.avatarImage));
   });
+
+  test('AccountRowSubtitleUpdatedForPassphraseError', async function() {
+    const testEmail = 'test@email.com';
+    await simulateSignedInState(SignedInState.SIGNED_IN, [{email: testEmail}]);
+
+    // First, it shows the user's email.
+    const accountSubtitle =
+        peoplePage.shadowRoot!.querySelector('#account-subtitle')!;
+    assertEquals(testEmail, accountSubtitle.textContent!.trim());
+
+    // When the passphrase needs to be entered, a message is displayed instead.
+    simulateSyncStatus({
+      signedInState: SignedInState.SIGNED_IN,
+      statusAction: StatusAction.ENTER_PASSPHRASE,
+      statusText: 'Enter the passphrase for $1',
+    });
+    assertEquals(
+        loadTimeData.substituteString(
+            peoplePage.syncStatus!.statusText!, testEmail),
+        accountSubtitle.textContent!.trim());
+  });
 });
 // </if>
